#!/usr/bin/env python
# -*- coding: utf-8 -*-

from gimpfu import *
import gimpcolor
import os, glob, re
# i18n
import gettext

locale_directory = gimp.locale_directory
gettext.install( "gimp20-batchwork", locale_directory, unicode=True )

'''
Batch to convert an image into a transparent + color indexed image
 Method taken from here :
 http://mcapewell.wordpress.com/2006/09/07/how-to-make-a-transparent-png-image-for-ie-6-in-the-gimp/

 - Open the original image.
 - Set a proper background colour as oposed to it being
   transparent. It is best to make this colour similar to the
   background colour of the website to generate the antialiasing
   in your image borders in order for the image to blend nicely.
 - Flatten the image (Image – Flatten image).
 - Add an alpha channel (Layer – Transparency – Add alpha channel).
 - Select the background color (Selection – By color).
 - Clear the background colour (Edit – Clear).
 - Convert the image to indexed color (Image – Mode – Indexed color).
 - Save the image to the final PNG file (File – Save as) and remember to check: Save color values from transparent pixels.
'''

BatchToTransparentIndexed_help = \
  _("Batch to convert an image into a transparent + color indexed image")
BatchToTransparentIndexed_description = BatchToTransparentIndexed_help

def python_fu_batch_to_transparent_indexed(
  infile,
  outfile):

  img = pdb.gimp_file_load( infile, infile)
  imgwidth = pdb.gimp_image_width(img)
  imgheight = pdb.gimp_image_height(img)

  pdb.gimp_image_flatten( img )
  imglayer= img.layers[0]
  pdb.gimp_layer_add_alpha(imglayer)
  pdb.gimp_context_set_background(gimpcolor.RGB(255,255,255))
  pdb.gimp_by_color_select(imglayer, gimpcolor.RGB(255,255,255), 0, \
    CHANNEL_OP_REPLACE, False, False, 0, False)
  pdb.gimp_edit_clear(imglayer)

  pdb.gimp_convert_indexed(img, NO_DITHER,  MAKE_PALETTE, 4, False, True, '')
  pdb.gimp_file_save( img, imglayer, outfile, outfile)
  pdb.gimp_image_delete(img)

  pdb.gimp_message( _("Done %s ") %(infile) )


# Register

register(
   "python-fu-batch-to-transparent-indexed",
   BatchToTransparentIndexed_description,
   BatchToTransparentIndexed_help,
   "Olivier Pons",
   "GPL License",
   "2011",
   _("Convertir en transparente + indexee"),
   "",
   [
      (PF_FILENAME, "infile", _("Input file"), "." ),
      (PF_FILENAME, "outfile", _("Output file"), "." ),
   ],
   [],
   python_fu_batch_to_transparent_indexed,
   menu="<Image>/Tools/Batchwork",
   domain=( "gimp20-batchwork", locale_directory)
   )


main()
